@@ -1,7 +1,7 @@
 from django.urls import path
 from rest_framework.routers import DefaultRouter
 
-from blog.views import EntryViewSet, ListUser, CommentViewSet
+from blog.views import EntryViewSet, ListUser, CommentViewSet, SyncConfig
 
 router = DefaultRouter()
 
@@ -10,4 +10,5 @@ router.register(r'comments', CommentViewSet, basename='comments')
 
 urlpatterns = [
     path('me/', ListUser.as_view()),
+    path('sync_config/', SyncConfig.as_view()),
 ] + router.urls
